import 'package:flutter/material.dart';

class DrawerItem extends StatelessWidget {

  IconData icon;
  String text;
  Color splashColor;
  Color normalForegroundColor, checkedForegroundColor;
  Color checkedBackgroundColor;
  Decoration backgroundDecoration;
  ShapeBorder selectCustomBorder;
  bool checked;
  GestureTapCallback onTap;


  DrawerItem({
    this.icon,
    this.text,
    this.splashColor,
    this.normalForegroundColor,
    this.checkedForegroundColor,
    this.checkedBackgroundColor,
    this.backgroundDecoration,
    this.selectCustomBorder,
    this.checked = false,
    this.onTap,
  }) {
    normalForegroundColor ??= Color(0xff414141);
    checkedForegroundColor ??= normalForegroundColor;
    checkedBackgroundColor ??= Color(0x779e9e9e);
    backgroundDecoration ??= BoxDecoration(color: checkedBackgroundColor, borderRadius: BorderRadius.only(topRight: Radius.circular(100), bottomRight: Radius.circular(100),));
    selectCustomBorder ??= RoundedRectangleBorder(borderRadius: BorderRadius.only(topRight: Radius.circular(100), bottomRight: Radius.circular(100),));
    checked ??= false;
  }

  @override
  Widget build(BuildContext context) =>
      Container(
        decoration: checked ? backgroundDecoration : null,
        margin: EdgeInsets.only(right: 8),
        child: InkWell(
          highlightColor: splashColor,
          splashColor: splashColor,
          customBorder: selectCustomBorder,
          onTap: onTap,
          child: Padding(
            padding: EdgeInsets.only(left: 16, right: 16, top: 16, bottom: 16),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                icon != null ? Icon(icon, color: checked ? checkedForegroundColor : normalForegroundColor,) : null,
                VerticalDivider(width: 24,),
                Text(text, style: TextStyle(color: checked ? checkedForegroundColor : normalForegroundColor),),
              ],
            ),
          ),
        ),
      );
}